
#ifndef __MYRADIO_GPIO_H_
#define __MYRADIO_GPIO_H_

#include <stdint.h>

#include "stm32f10x.h"
#include "stm32f10x_gpio.h"
#include "stm32f10x_spi.h"
#include "board.h"

#ifndef SPI_SOFT_3LINE
    #define SPI_HARD
#endif
// #define SPI_SOFT_3LINE

typedef void (*RADIO_GPIO_CALLBACK)(uint8_t index);

//-------------射频模块引脚映射到转接板排针---------------
//IO1用于射频中断响应
#define RF_PAN3031_IRQ_PIN           BOARD_PIN_SPI_GPIOB  //
#define RF_PAN3031_IRQ_PORT          BOARD_PORT_SPI_GPIOB
#define RF_PAN3031_IRQ               RF_PAN3031_IRQ_PORT, RF_PAN3031_IRQ_PIN          //
//
#define RF_PAN3031_IO5_PIN           BOARD_PIN_SPI_GPIOC  //
#define RF_PAN3031_IO5_PORT          BOARD_PORT_SPI_GPIOC
#define RF_PAN3031_IO5               RF_PAN3031_IO5_PORT, RF_PAN3031_IO5_PIN          //
//
#define RF_PAN3031_IO8_PIN           BOARD_PIN_SPI_GPIOA  //
#define RF_PAN3031_IO8_PORT          BOARD_PORT_SPI_GPIOA
#define RF_PAN3031_IO8               RF_PAN3031_IO8_PORT, RF_PAN3031_IO8_PIN          //
//
#define RF_PAN3031_IO11_PIN          BOARD_PIN_SPI_GPIOD  //
#define RF_PAN3031_IO11_PORT         BOARD_PORT_SPI_GPIOD
#define RF_PAN3031_IO11              RF_PAN3031_IO11_PORT, RF_PAN3031_IO11_PIN          //
//外部PA和LNA控制脚
#define RF_EXTPA_RE_PIN      BOARD_PIN_SPI_GPIOE  //
#define RF_EXTPA_RE_PORT     BOARD_PORT_SPI_GPIOE
#define RF_EXTPA_RE          RF_EXTPA_RE_PORT, RF_EXTPA_RE_PIN          //
#define RF_EXTPA_TE_PIN      BOARD_PIN_SPI_GPIOF  //
#define RF_EXTPA_TE_PORT     BOARD_PORT_SPI_GPIOF
#define RF_EXTPA_TE          RF_EXTPA_TE_PORT, RF_EXTPA_TE_PIN          //
//-------------射频模块引脚映射到转接板排针---------------END

uint8_t READ_RF_PAN3031_IRQ(void);
void RF_PAN3031_IRQ_H(void);
void RF_PAN3031_IRQ_L(void);

void RF_EXT_PA_RE_H(void);
void RF_EXT_PA_RE_L(void);
void RF_EXT_PA_TE_H(void);
void RF_EXT_PA_TE_L(void);

#define RF_EXT_PA_TO_TX() RF_EXT_PA_TE_H();RF_EXT_PA_RE_L()
#define RF_EXT_PA_TO_RX() RF_EXT_PA_TE_L();RF_EXT_PA_RE_H()
#define RF_EXT_PA_TO_IDLE() RF_EXT_PA_TE_L();RF_EXT_PA_RE_L()

void BOARD_SPI_NSS_H(void);
void BOARD_SPI_NSS_L(void);

//-------------将封装的API映射到射频模块硬件层---------------
void myRadio_gpio_init(RADIO_GPIO_CALLBACK cb);
uint8_t myRadioSpi_rwByte(uint8_t byteToWrite);
void myRadioSpi_wBuffer(uint8_t* pData, uint8_t len);
void myRadioSpi_rBuffer(uint8_t* pData, uint8_t len);

#define SpiReadWrite(p) myRadioSpi_rwByte(p)
#define SpiWriteData(p1, p2) myRadioSpi_wBuffer(p2, p1)
#define SpiReadData(p1, p2) myRadioSpi_rBuffer(p2, p1)
//-------------将封装的API映射到射频模块硬件层---------------END
#endif
